@@ -35,7 +35,8 @@ preprocess.for.type = function( x, nastrings ){
   
   x = as.character(x)
   x[ x %in% nastrings ] <- NA
-  x = tolower( stringr::str_trim(x) )
+  # ignore bad characters
+  x = tolower( str_trim_fixed(x) )
 
   return(x)
 
@@ -119,4 +120,7 @@ validatecolnames = function(x, checknames){
     These names are available: [{cc(setdiff(names(x), checknames), sep=", ")}].
   '))
 
-}
\ No newline at end of file
+}
+
+str_trim_fixed = function(x) stringr::str_trim(iconv(x, 'UTF-8', 'UTF-8//IGNORE'))
+
